[Pkg-gnupg-commit] [gpgme] 04/412: example email

Daniel Kahn Gillmor dkg at fifthhorseman.net
Thu Sep 22 21:26:03 UTC 2016


This is an automated email from the git hooks/post-receive script.

dkg pushed a commit to branch master
in repository gpgme.

commit 8345bf6f43c4f671124eaa1b713a7f5ac5780cbd
Author: Ben McGinnes <ben at adversary.org>
Date:   Sun May 17 02:35:24 2015 +1000

    example email
    
    * changed joe at foo.bar to joe at example.org as it is only a matter of time
      before ICANN actually creates bar as a gTLD, if they haven't already.
---
 lang/py3-pyme/examples/delkey.py       | 4 ++--
 lang/py3-pyme/examples/exportimport.py | 4 ++--
 lang/py3-pyme/examples/genkey.py       | 2 +-
 lang/py3-pyme/examples/signverify.py   | 8 ++++----
 4 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/lang/py3-pyme/examples/delkey.py b/lang/py3-pyme/examples/delkey.py
index e79e120..8bdb85b 100755
--- a/lang/py3-pyme/examples/delkey.py
+++ b/lang/py3-pyme/examples/delkey.py
@@ -17,7 +17,7 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 # Sample of key deletion
-# It deletes keys for joe at foo.bar generated by genkey.pl script
+# It deletes keys for joe at example.org generated by genkey.pl script
 
 from pyme import core
 
@@ -29,6 +29,6 @@ core.check_version(None)
 
 c = core.Context()
 # 0 in keylist means to list not only public but secret keys as well.
-for thekey in [x for x in c.op_keylist_all("joe at foo.bar", 0)]:
+for thekey in [x for x in c.op_keylist_all("joe at example.org", 0)]:
     # 1 in delete means to delete not only public but secret keys as well.
     c.op_delete(thekey, 1)
diff --git a/lang/py3-pyme/examples/exportimport.py b/lang/py3-pyme/examples/exportimport.py
index 5390463..45f2f51 100755
--- a/lang/py3-pyme/examples/exportimport.py
+++ b/lang/py3-pyme/examples/exportimport.py
@@ -17,7 +17,7 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 # Sample of export and import of keys
-# It uses keys for joe at foo.bar generated by genkey.pl script
+# It uses keys for joe at example.org generated by genkey.pl script
 
 import sys
 from pyme import core
@@ -27,7 +27,7 @@ core.check_version(None)
 expkey = core.Data()
 c = core.Context()
 c.set_armor(1)
-user = "joe at foo.bar"
+user = "joe at example.org"
 
 print(" - Export %s's public keys - " % user)
 c.op_export(user, 0, expkey)
diff --git a/lang/py3-pyme/examples/genkey.py b/lang/py3-pyme/examples/genkey.py
index 6c4b2d8..0b4feee 100755
--- a/lang/py3-pyme/examples/genkey.py
+++ b/lang/py3-pyme/examples/genkey.py
@@ -35,7 +35,7 @@ Subkey-Type: RSA
 Subkey-Length: 2048
 Name-Real: Joe Tester
 Name-Comment: with stupid passphrase
-Name-Email: joe at foo.bar
+Name-Email: joe at example.org
 Passphrase: abcdabcdfs
 Expire-Date: 2020-12-31
 </GnupgKeyParms>
diff --git a/lang/py3-pyme/examples/signverify.py b/lang/py3-pyme/examples/signverify.py
index 20c9181..0a1660e 100755
--- a/lang/py3-pyme/examples/signverify.py
+++ b/lang/py3-pyme/examples/signverify.py
@@ -17,7 +17,7 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 # Sample of unattended signing/verifying of a message.
-# It uses keys for joe at foo.bar generated by genkey.pl script
+# It uses keys for joe at example.org generated by genkey.pl script
 
 import sys
 from pyme import core, callbacks
@@ -28,10 +28,10 @@ core.check_version(None)
 plain = core.Data("Test message")
 sig = core.Data()
 c = core.Context()
-user = "joe at foo.bar"
+user = "joe at example.org"
 
 c.signers_clear()
 # Add joe at foo.bar's keys in the list of signers
 for sigkey in c.op_keylist_all(user, 1):
     if sigkey.can_sign:
         c.signers_add(sigkey)
@@ -41,7 +41,7 @@ if not c.signers_enum(0):
 
 # This is a map between signer e-mail and its password
 passlist = {
-    "<joe at foo.bar>": "abcdabcdfs"
+    "<joe at example.org>": "abcdabcdfs"
     }
     
 # callback will return password based on the e-mail listed in the hint.
@@ -28,10 +28,10 @@ core.check_version(None)
 
 c.signers_clear()
-# Add joe at foo.bar's keys in the list of signers
+# Add joe at example.org's keys in the list of signers
 for sigkey in c.op_keylist_all(user, 1):
     if sigkey.can_sign:

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-gnupg/gpgme.git



More information about the Pkg-gnupg-commit mailing list